@@ -95,9 +95,14 @@ def handle_client(conn, addr):
             filetype = msg.split("*-*/")[0].split(".")[1]
             content = msg.split("*-*/")[1]
 
-            f = open(f'{SAVE_DIR}/{name}.{filetype}', 'w+')
-            f.write(content)
-            f.close()
+            if osofmachine == 'windows':
+                f = open(f'{SAVE_DIR}\{name}.{filetype}', 'w+')
+                f.write(content)
+                f.close()
+            else:
+                f = open(f'{SAVE_DIR}/{name}.{filetype}', 'w+')
+                f.write(content)
+                f.close()
 
             conn.send("200".encode(FORMAT))
 
